import { scaleOrdinal } from 'd3';

const colorScale = scaleOrdinal()
  .domain(['apple', 'lemon'])
  .range(['#c11d1d', '#eae600']);

const radiusScale = scaleOrdinal()
  .domain(['apple', 'lemon'])
  .range([50, 30]);

const xPosition = i => i * 120 + 60;

export const fruitBowl = (selection, props) => {
  const { fruits, height } = props;
  const groupTransform = (d, i) =>
    `translate(${xPosition(i)},${height / 2})`;
  
  const groups = selection.selectAll('g')
    .data(fruits, d => d.id);
  const groupsEnter = groups
    .enter().append('g')
      .attr('transform', groupTransform);
  groupsEnter
    .merge(groups)
    .transition().duration(1000)
      .attr('transform', groupTransform);
  groups.exit()
    .transition().duration(1000)
    .remove();
  
  groupsEnter.append('circle')
      .attr('r', 0)
    .merge(groups.select('circle'))
      .attr('fill', d => colorScale(d.type))
    .transition().duration(1000)
      .attr('r', d => radiusScale(d.type));
  groups.exit().select('circle')
    .transition().duration(1000)
      .attr('r', 0);
  
  groupsEnter.append('text')
      .attr('opacity', 0)
    .merge(groups.select('text'))
      .text(d => d.type)
    .transition().duration(1000)
      .attr('opacity', 1);
  groups.exit().select('text')
    .transition().duration(1000)
      .attr('opacity', 0);
}